from typing import Any, List, Optional
import os
from pathlib import Path
from fastapi import APIRouter, Depends, HTTPException
from sqlalchemy.orm import Session

from beastiary import crud, schemas
from beastiary.api.core import check_for_new_samples

router = APIRouter()


from pydantic import BaseModel


class File(BaseModel):
    name: str
    path: str
    is_dir: bool


class Dir(BaseModel):
    path: str
    parent: str
    files: List[File]


@router.get("/", response_model=Dir)
def list_directory(path: Optional[str] = None) -> dict:
    """
    List the folders/files in a diretory
    """
    if not path:
        path = os.path.abspath(os.getcwd())
    files = [
        {
            "name": name,
            "path": os.path.join(path, name),
            "is_dir": os.path.isdir(os.path.join(path, name)),
        }
        for name in os.listdir(path)
        if not name.startswith(".")
    ]

    sorted_files = sorted(files, key=lambda d: d["is_dir"], reverse=True)

    directory = {
        "path": path,
        "parent": str(Path(path).parent.absolute()),
        "files": sorted_files,
    }
    return directory



from typing import Any, List, Tuple
import math
from beastiary.models.trace import Trace
from fastapi import APIRouter, Depends, HTTPException, Path
from sqlalchemy.orm import Session

from beastiary import crud, schemas
from beastiary.api import deps
from beastiary.api.core import check_for_new_samples
from beastiary.log import logger

router = APIRouter()


@router.get("/", response_model=List[schemas.Sample])
def get_samples(
    trace_id: int,
    skip: int = 0,
    limit: int = 100,
    db: Session = Depends(deps.get_db),
) -> Any:
    """
    Retrieve samples.
    """
    trace = crud.trace.get(db, trace_id)
    if not trace:
        raise HTTPException(404, detail="Trace not found!")

    samples = crud.sample.get_multi_by_trace(
        db, trace_id=trace.id, skip=skip, limit=limit
    )

    logger.debug(f"{limit} samples requested - {len(samples)} found")
    if len(samples) < limit:

        logger.debug(f"Checking for new samples in {trace.path}")
        try:
            check_for_new_samples(db, trace=trace)
        except Exception as e:
            raise HTTPException(500, detail=f"Could read samples in {trace.path}")
        # get samples
        samples = crud.sample.get_multi_by_trace(
            db, trace_id=trace.id, skip=skip, limit=limit
        )
    logger.debug(f"Returning {len(samples)} samples")
    return samples



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['beastiary',
 'beastiary.api',
 'beastiary.api.endpoints',
 'beastiary.crud',
 'beastiary.db',
 'beastiary.models',
 'beastiary.schemas']

package_data = \
{'': ['*'],
 'beastiary': ['webapp-dist/*', 'webapp-dist/css/*', 'webapp-dist/js/*']}

install_requires = \
['SQLAlchemy>=1.4.22,<2.0.0',
 'aiofiles<0.6.0',
 'fastapi[all]>=0.67.0,<0.68.0',
 'typer[all]>=0.3.2,<0.4.0']

entry_points = \
{'console_scripts': ['beastiary = beastiary.cli:app']}

setup_kwargs = {
    'name': 'beastiary',
    'version': '1.4.4',
    'description': '',
    'long_description': '![beastiary logo](https://beastiary.wytamma.com/images/logo.png)\n\n\n[![PyPi](https://img.shields.io/pypi/v/beastiary.svg)](https://pypi.org/project/beastiary/)\n[![tests](https://github.com/Wytamma/beastiary/actions/workflows/test.yml/badge.svg)](https://github.com/Wytamma/beastiary/actions/workflows/test.yml)\n[![cov](https://codecov.io/gh/Wytamma/beastiary/branch/master/graph/badge.svg)](https://codecov.io/gh/Wytamma/beastiary)\n[![docs](https://github.com/Wytamma/beastiary/actions/workflows/docs.yml/badge.svg)](https://beastiary.wytamma.com/)\n\nBeastiary is designed for visualising and analysing MCMC trace files generated from Bayesian phylogenetic analyses. Beastiary works in real-time and on remote servers (e.g. a HPC). Its goal is to be a beautiful and simple yet powerful tool for Bayesian phylogenetic inference.\n\n---\n\n**Documentation**: <a href="https://beastiary.wytamma.com" target="_blank">https://beastiary.wytamma.com</a>\n\n**Source Code**: <a href="https://github.com/Wytamma/beastiaryi" target="_blank">https://github.com/Wytamma/beastiary</a>\n\n---\n\n## Installation\n```bash\npip install beastiary\n```\n\n## Use\nTo start beastiary use the `beastiary` command. \n\n```bash\nbeastiary\n```\n\n![](https://beastiary.wytamma.com/images/screen_shot_dark.png)\n\nFor more information read the [docs](https://beastiary.wytamma.com/).\n',
    'author': 'Wytamma Wirth',
    'author_email': 'wytamma.wirth@me.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6.2,<4.0',
}


setup(**setup_kwargs)
